Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DB ¶
type DB interface {
// Revoke is the method to revoke the supplied tail
Revoke(ctx context.Context, tail []byte, apiKeyID []byte) error
// Check will check whether any of the supplied tails have been revoked
Check(ctx context.Context, tails [][]byte) (bool, error)
}
DB is the interface for a revocation DB.
Click to show internal directories.
Click to hide internal directories.